about summary refs log tree commit diff
path: root/src/librustc/query
diff options
context:
space:
mode:
authorEduard-Mihai Burtescu <edy.burt@gmail.com>2020-03-18 03:48:17 +0200
committerEduard-Mihai Burtescu <edy.burt@gmail.com>2020-03-19 14:36:04 +0200
commite8f1dfae64e302c0da846d215697b323bb1ee0a2 (patch)
treeae07c8ecd9ad1d5dc757d0897d5a700b073f74d9 /src/librustc/query
parent3c6f982cc908aacc39c3ac97f31c989f81cc213c (diff)
downloadrust-e8f1dfae64e302c0da846d215697b323bb1ee0a2.tar.gz
rust-e8f1dfae64e302c0da846d215697b323bb1ee0a2.zip
hir: replace "items" terminology with "nodes" where appropriate.
Diffstat (limited to 'src/librustc/query')
-rw-r--r--src/librustc/query/mod.rs10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/librustc/query/mod.rs b/src/librustc/query/mod.rs
index de35c6d87e6..d5f41aac43a 100644
--- a/src/librustc/query/mod.rs
+++ b/src/librustc/query/mod.rs
@@ -71,20 +71,20 @@ rustc_queries! {
             desc { |tcx| "HIR module items in `{}`", tcx.def_path_str(key.to_def_id()) }
         }
 
         // An HIR item with a `LocalDefId` that can own other HIR items which do
         // not themselves have a `LocalDefId`.
         // This can be conveniently accessed by methods on `tcx.hir()`.
         // Avoid calling this query directly.
-        query hir_owner(key: LocalDefId) -> &'tcx HirOwner<'tcx> {
+        query hir_owner(key: LocalDefId) -> &'tcx crate::hir::Owner<'tcx> {
             eval_always
             desc { |tcx| "HIR owner of `{}`", tcx.def_path_str(key.to_def_id()) }
         }
 
         // The HIR items which do not themselves have a `LocalDefId` and are
         // owned by another HIR item with a `LocalDefId`.
         // This can be conveniently accessed by methods on `tcx.hir()`.
         // Avoid calling this query directly.
-        query hir_owner_items(key: LocalDefId) -> &'tcx HirOwnerItems<'tcx> {
+        query hir_owner_nodes(key: LocalDefId) -> &'tcx crate::hir::OwnerNodes<'tcx> {
             eval_always
             desc { |tcx| "HIR owner items in `{}`", tcx.def_path_str(key.to_def_id()) }
         }
@@ -71,20 +71,20 @@ rustc_queries! {
         }
 
-        // An HIR item with a `LocalDefId` that can own other HIR items which do
+        // An HIR node with a `LocalDefId` that can own other HIR nodes which do
         // not themselves have a `LocalDefId`.
         // This can be conveniently accessed by methods on `tcx.hir()`.
@@ -71,20 +71,20 @@ rustc_queries! {
         }
 
-        // The HIR items which do not themselves have a `LocalDefId` and are
-        // owned by another HIR item with a `LocalDefId`.
+        // The HIR nodes which do not themselves have a `LocalDefId` and are
+        // owned by another HIR node with a `LocalDefId`.
         // This can be conveniently accessed by methods on `tcx.hir()`.
         // Avoid calling this query directly.